@@ -770,7 +770,7 @@ class RuleSet(ABC):
                 if return_nones is True:
                     return act, pd.Series({str(self[i].condition): activations[i].nones for i in range(len(self))})
                 return act
-            except MemoryError:
+            except (MemoryError, np.core._exceptions._ArrayMemoryError):
                 act = Activation(activations[0], optimize=activations[0].optimize, to_file=activations[0].to_file)
                 for a in activations:
                     act = act or a
